@@ -322,13 +322,15 @@ class AVISO_fetch(object):
             # Will download blocks of at most 5MB
             #   i.e. 4e7 floats of 32bits.
             dblocks = min(100, max(1, int(4e7/self.slice_size)))
+            self.logger.debug("Will download %s in blocks of %s" % \
+                    (v, dblocks))
 
             ti = numpy.arange(self.cfg['limits']['t_ini'],
                     self.cfg['limits']['t_fin'],
                     self.cfg['limits']['t_step'])
 
             blocks = ti[::dblocks]
-            if ti[-1] not in blocks:
+            if self.cfg['limits']['t_fin'] not in blocks:
                 blocks = numpy.append(blocks, self.cfg['limits']['t_fin'])
 
             #------
@@ -358,6 +360,7 @@ class AVISO_fetch(object):
             Latlimits = self.cfg['limits']['Latlimits']
 
             for b1, b2 in zip(blocks[:-1], blocks[1:]):
+                # Acho que tem um problema aqui, não deveria de ser blocks[-1]
                 self.logger.debug("From %s to %s of %s" % (b1, b2, blocks[-1]))
                 ind = numpy.nonzero((ti>=b1) & (ti<b2))
                 for i in range(ntries):
@@ -547,18 +550,45 @@ class Aviso_map(object):
         #ssh = Arrayterator(dataset)[t_ini:t_fin:t_step]
 
 
-def mask_shallow(ncfile, zfile, zlimit):
+def mask_shallow(ncfile, zlimit=-150, zfile=None):
     """ Mask all variables in vars @ gridpoints shallower than mindepth
 
          Use http://opendap.ccst.inpe.br/Misc/etopo2/ETOPO2v2c_f4.nc
+
+         In the future move it out of here, into a different support
+           command line
     """
+    if zfile is None:
+        zfile = "http://opendap.ccst.inpe.br/Misc/etopo2/ETOPO2v2c_f4.nc"
+
     nc = netCDF4.Dataset(ncfile, 'a')
     Lat = nc.variables['latitude'][:]
     Lon = nc.variables['longitude'][:]
 
     #Lon,Lat = numpy.meshgrid(self.data['lon'],self.data['lat'])
-    from fluid.common.common import get_bathymery
-    z = get_bathymery(Lat, Lon, etopo_file=zfile)
+    #from fluid.common.common import get_bathymery
+    #z = get_bathymery(Lat, Lon, etopo_file=zfile)
+    # ========================================================================
+    # Not cute, but works for now.
+    ncz = netCDF4.Dataset(zfile, 'r')
+    # -180:180
+    lon_z = ncz.variables['x'][:]
+    lat_z = ncz.variables['y'][:]
+
+    # If input 0:360
+    ind = Lon > 180
+    Lon[ind] = Lon[ind] - 360
+
+    I = Lat.size
+    J = Lon.size
+    z = np.empty((I, J))
+    for i in range(I):
+        for j in range(J):
+            x_ind = (np.absolute(Lon[j] - lon_z)).argmin()
+            y_ind = (np.absolute(Lat[i] - lat_z)).argmin()
+            z[i, j] = ncz.variables['z'][y_ind, x_ind]
+
+    # ========================================================================
     ind = z > zlimit
     for v in nc.variables.keys():
         if nc.variables[v].dimensions == (u'time', u'latitude', u'longitude'):
